import React from "react";
import { Switch as RmwcSwitch, SwitchProps } from "@rmwc/switch";
import { FormComponentProps } from "~/types";
import pick from "lodash/pick";
import { FormElementMessage } from "~/FormElementMessage";
import { getClasses } from "~/Helpers";

type Props = FormComponentProps &
    SwitchProps & {
        // Description beneath the switch.
        description?: string;

        // Optional class name.
        className?: string;
    };

/**
 * Switch component can be used to store simple boolean values.
 */
class Switch extends React.Component<Props> {
    static rmwcProps = ["id", "disabled", "checked", "label", "rootProps", "className"];

    onChange = (e: React.SyntheticEvent<HTMLElement>) => {
        this.props.onChange && this.props.onChange((e.target as any).checked);
    };

    public override render() {
        const { value, description, validation } = this.props;

        const { isValid: validationIsValid, message: validationMessage } = validation || {};

        return (
            <React.Fragment>
                <RmwcSwitch
                    {...getClasses({ ...pick(this.props, Switch.rmwcProps) }, "webiny-ui-switch")}
                    checked={Boolean(value)}
                    onChange={this.onChange}
                />

                {validationIsValid === false && (
                    <FormElementMessage error>{validationMessage}</FormElementMessage>
                )}

                {validationIsValid !== false && description && (
                    <FormElementMessage>{description}</FormElementMessage>
                )}
            </React.Fragment>
        );
    }
}

export { Switch };
